<?php
require_once 'Symfony/Component/EventDispatcher/autoload.php';
require_once 'Symfony/Component/HttpKernel/autoload.php';
require_once 'Symfony/Component/Mercure/autoload.php';
require_once 'Twig/autoload.php';
